Add A New Template Center To Your Plone Site
############################################

I assume you want to add the center to the Plone site root ('Home'). Therefor go to this site root and
choose from the Plone menu on the left 'Add new'. You get in this menu an entry to create a new
'Template Center' (see the screenshot below).

.. image:: images/create_template_center.png
   :width: 600


Click on this entry and you get the form below. This is the edit form to create and configure a new
Template Center in your Plone site.

.. image:: images/template_center_form1.png
   :width: 600


Fill in the fields in the edit form of the Template Center. All fields has a description of their expected values.
Don't miss to go through the register of the edit form dialog.

The second register ('Instructions') (see screenshot below) holds some fields for instructions about installation of the templates, reporting template
bugs and for an information text about searching for templates usable with older product versions. This text could
be displayed, if the versions were removed from the listing of the configuration setting of this add-on.

.. image:: images/template_center_form2.png
   :width: 600

The third register ('Special email addresses') (see screenshot below) has a field to set an address for messages to the template
reviewer on the site.

.. image:: images/template_center_form3.png
   :width: 600

Once you are finished with adding values to the edit form, save the form. If you missed to edit a form field,
you will get an error message and could fill in the necessary information into the appropriate form field.

Publish The New Template Center
*******************************

Once you finished with the edit form of the Template Center and saved your changes you need to publish the center.
You could do this by a click on the entry 'State: Private' in the menubar on the left site. Choose the entry 'Publish'
and you are done.

Sharing: Enable Members To Add Projects
***************************************

The logged in users are not able to add projects to the Template Center yet. You could enable this by a mouse click
on the entry 'Sharing' in menubar on the left site (see screenshot below). This shows the edit menu for sharing
and you could tick the checkbox 'Can add' for 'logged-in-users' (see screenshot below) to enable the members of
the Plone site to add their template projects to the center.

.. image:: images/template_center_sharing.png
   :width: 600

